package com.ruoyi.zongzhi.service;

import java.util.List;
import com.ruoyi.zongzhi.domain.TcNetworkArticle;

/**
 * 网络文章Service接口
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
public interface ITcNetworkArticleService 
{
    /**
     * 查询网络文章
     * 
     * @param id 网络文章主键
     * @return 网络文章
     */
    public TcNetworkArticle selectTcNetworkArticleById(Long id);

    /**
     * 查询网络文章列表
     * 
     * @param tcNetworkArticle 网络文章
     * @return 网络文章集合
     */
    public List<TcNetworkArticle> selectTcNetworkArticleList(TcNetworkArticle tcNetworkArticle);

    /**
     * 新增网络文章
     * 
     * @param tcNetworkArticle 网络文章
     * @return 结果
     */
    public int insertTcNetworkArticle(TcNetworkArticle tcNetworkArticle);

    /**
     * 修改网络文章
     * 
     * @param tcNetworkArticle 网络文章
     * @return 结果
     */
    public int updateTcNetworkArticle(TcNetworkArticle tcNetworkArticle);

    /**
     * 批量删除网络文章
     * 
     * @param ids 需要删除的网络文章主键集合
     * @return 结果
     */
    public int deleteTcNetworkArticleByIds(Long[] ids);

    /**
     * 删除网络文章信息
     * 
     * @param id 网络文章主键
     * @return 结果
     */
    public int deleteTcNetworkArticleById(Long id);
}
